Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Filter ¶
type Filter struct {
// Regexp a regular expression to match with
Regexp string `yaml:"regexp"`
// SetValue is called with the regular expression and RNode as a string
SetValue SetFn
}
Filter is a kyaml Filter that applies regular expressions
type SliceFilter ¶
type SliceFilter struct {
// ReSlice is a slice of regular expressions for string extraction
ReSlice []string `yaml:"reSlice"`
// SetValue is called with for each regular expression and RNode as a string
SetValue SetFn
}
SliceFilter is the spec for the kustomize function.
Click to show internal directories.
Click to hide internal directories.